@@ -1,17 +1,19 @@
-from tkinter import *
-from tkinter import ttk
+from tkinter import PhotoImage, NORMAL, END, DISABLED, Text, HORIZONTAL, ttk
 from ttkthemes import ThemedTk
+from importlib.metadata import version
 import threading
 import subprocess
 import logging
-from types import SimpleNamespace
 
-from .collect import GameCollection, GameStatus, CollectionStatus, clipboard
+from .collect import GameStatus, CollectionStatus, clipboard
 from .res import file_res
 
 logger = logging.getLogger(__name__)
 
 class TetsudoruCommands:
+    def __init__(self, gui=None):
+        self.gui = gui
+
     strings = [
         "tetsudoru -1 | grep -v '[きぎただあさざかが]'",
         "tetsudoru -1 | grep -v '[きぎただあさざかがつっづしじんまちぢ]'",
@@ -19,6 +21,8 @@ class TetsudoruCommands:
     ]
     def to_clipboard(self, idx):
         subprocess.run(['xclip', '-sel', 'c'], input=self.strings[idx - 1], text=True)
+        if self.gui is not None:
+            self.gui.new_status(f"Sent search string for Tetsudoru ({idx} guesses)")
 
 class ClipwaitThread:
     event_name = "<<NewClipboard>>"
@@ -33,10 +37,10 @@ class ClipwaitThread:
         self.gui.root.event_generate(self.event_name)
     def start(self):
         threading.Thread(target=self._exec, daemon=self.daemon).start()
-        logger.info('New clip wait thread spawned')
+        logger.debug('New clip wait thread spawned')
     def hook(self):
         dat = clipboard()
-        self.gui.update_clipboard(dat)
+        # self.gui.update_clipboard(dat)
         if matchp := self.col.find_matching_game(dat):
             self.gui.update_games_view(matchp)
         match self.col.status():
@@ -69,8 +73,6 @@ class Worker:
         pass
 
 class GUI:
-    tetsudoru = TetsudoruCommands()
-
     _icons = {
         GameStatus.COLLECTED: 'emblem-default-symbolic.png',
         GameStatus.UNCOLLECTED: 'emblem-error.png',
@@ -85,7 +87,7 @@ class GUI:
         self.workers = list()
         self.date = config.date
         self.complete = False
-        self.db = config.db()
+        self.tetsudoru = TetsudoruCommands(self)
         self.root.title(f'{config.program_name}: {config.date:%Y-%m-%d}')
         self.root.grid_rowconfigure(0, weight=1)
         self.root.grid_columnconfigure(0, weight=1)
@@ -93,10 +95,10 @@ class GUI:
             self._icons[k] = PhotoImage(file=file_res(v), format='png')
         self.clipwait_thread = ClipwaitThread(self, daemon=True)
         self.col.inject_gui(self)
-        self.col.inject_db(self.db)
 
     def _title(self):
-        return f"Collecting for {self.date:%Y-%m-%d}"
+        return "Version {}; collecting for {:%Y-%m-%d}".format(
+            version("autowordle"), self.date)
 
     def add_worker(self, worker, kickoff_event):
         worker.inject_gui(self, kickoff_event)
@@ -116,7 +118,7 @@ class GUI:
         new_status = game.status()
         self.games_view.item(
             game.short_name,
-            values=(game.name, new_status.as_str()),
+            values=(game.name, game.status_str()),
             image=self._icons[new_status])
         if new_status == GameStatus.COLLECTED:
             self.progress_bar.step(1)
@@ -168,12 +170,14 @@ class GUI:
             height=len(self.col.collection))
         self.games_view.column('#0', width=50)
         self.games_view.heading('name', text='Name')
+        self.games_view.column('name', width=150)
         self.games_view.heading('status', text='Status')
+        self.games_view.column('status', width=300)
         self.games_view.grid(column=1, row=1, columnspan=2)
         for game in self.col.collection:
             self.games_view.insert(
                 '', 'end', game.short_name,
-                values=(game.name, game.status().as_str()),
+                values=(game.name, game.status_str()),
                 image=self._icons[game.status()])
     def _add_status_bar(self, frm):
         ttk.Separator(frm, orient=HORIZONTAL).grid(row=1, column=0, columnspan=3, sticky='ew')
