@@ -16,3 +16,7 @@ magick \
     -pointsize 13 -draw "text 0,30 'Guesses'" \
     -draw "text 0,70 'Accuracy'" \
     ${1-redactle-base.png}
+
+magick \
+    -size 50x75 xc:white -strokewidth 5 -stroke '#DD2E44' \
+    -draw 'line 0,0 50,75' -draw 'line 0,75 50,0' ${2-missing-image.png}
