@@ -1,7 +1,8 @@
 #!/usr/bin/env python3
 
-from datetime import datetime, timedelta
+from datetime import timedelta
 from aw_client import ActivityWatchClient
+import logging
 
 QUERY = """
 events = query_bucket('aw-watcher-window_fiventsu');
@@ -9,6 +10,7 @@ not_afk = flood(query_bucket(find_bucket("aw-watcher-afk_fiventsu")));
 not_afk = filter_keyvals(not_afk, "status", ["not-afk"]);
 RETURN = filter_period_intersect(events, not_afk);
 """
+_logger = logging.getLogger(__name__)
 
 class Query:
     def __repr__(self):
@@ -19,9 +21,11 @@ class Query:
         )
     def __init__(self, cfg):
         self.events = None
-        self.date = cfg.date - timedelta(hours=18)
-        self.window_titles = cfg.window_titles()
         self.timezone = cfg.timezone
+        last_completed_time = cfg.db.latest_generated_image()
+        self.date = max(cfg.date - timedelta(hours=18), last_completed_time)
+        _logger.info(f'Timer is counting from {self.date:%d%H%MJ}')
+        self.window_titles = cfg.window_titles()
 
     def _ensure_query_run(self):
         if self.events is None:
